import type { Resolver } from './resolver/index.js';
import { type Transformer } from './transformer/index.js';
export declare type Watcher = {
    close: () => Promise<void>;
};
export declare type LocalsConvention = 'camelCase' | 'camelCaseOnly' | 'dashes' | 'dashesOnly' | undefined;
export interface RunnerOptions {
    pattern: string;
    outDir?: string | undefined;
    watch?: boolean | undefined;
    localsConvention?: LocalsConvention | undefined;
    declarationMap?: boolean | undefined;
    transformer?: Transformer | undefined;
    resolver?: Resolver | undefined;
    /**
     * The option compatible with sass's `--load-path`. It is an array of relative or absolute paths.
     * @example ['src/styles']
     * @example ['/home/user/repository/src/styles']
     */
    sassLoadPaths?: string[] | undefined;
    /**
     * The option compatible with less's `--include-path`. It is an array of relative or absolute paths.
     * @example ['src/styles']
     * @example ['/home/user/repository/src/styles']
     */
    lessIncludePaths?: string[] | undefined;
    /**
     * Silent output. Do not show "files written" messages.
     * @default false
     */
    silent?: boolean | undefined;
    /** Working directory path. */
    cwd?: string | undefined;
}
declare type OverrideProp<T, K extends keyof T, V extends T[K]> = Omit<T, K> & {
    [P in K]: V;
};
/**
 * Run typed-css-module.
 * @param options Runner options.
 * @returns Returns `Promise<Watcher>` if `options.watch` is `true`, `Promise<void>` if `false`.
 */
export declare function run(options: OverrideProp<RunnerOptions, 'watch', true>): Promise<Watcher>;
export declare function run(options: RunnerOptions): Promise<void>;
export {};
